@@ -371,7 +371,7 @@ class TIBasicParser:
 			statement = parsing_utils.noStringReplace(r'\[([A-J])\]', r'matrix_\1', statement)
 			statement = parsing_utils.noStringReplace(r'(matrix_[A-J])\((.+),(.+?)\)', lambda m: m.group(1) + '[' + m.group(2) + ' - 1][' + m.group(3) + ' - 1]', statement)
 			statement = parsing_utils.noStringReplace(r'len\((matrix_[A-J])\)\s*=\s*\[(.+),(.+?)\]', r'\1.reshape(\2, \3)', statement)
-			statement = parsing_utils.noStringReplace(r'(matrix_[A-J])\s*=\s*(\[\[.*\]\])', r'\1 = Matrix(\2)', statement)
+			statement = parsing_utils.noStringReplace(r'(matrix_[A-J])\s*=\s*(\[\[.*\]\])', lambda m: m.group(1) + ' = Matrix(' + m.group(2).replace('][', '], [') + ')', statement)
 			self.UTILS['matrix']['enabled'] = True
 
 		if 'int(' in ' '.join(statement):
@@ -399,6 +399,9 @@ class TIBasicParser:
 			for statement_index, item in enumerate(statement):
 				statement[statement_index] = parsing_utils.toValidEqn(item)
 
+		if 'Ans' in ''.join(statement):
+			self.pythonCode = parsing_utils.last_line_without_variable_assignment_ans(self.pythonCode)
+
 		if isinstance(statement, list) and len(statement) == 1:
 			statement = statement[0]
 
